@@ -402,10 +402,16 @@ string PrintableSourceRange(SourceRange range) {
   return PrintableLoc(range.getBegin()) + " - " + PrintableLoc(range.getEnd());
 }
 
-string PrintableDecl(const Decl* decl) {
-  std::string buffer;    // llvm wants regular string, not our versa-string
+string PrintableDecl(const Decl* decl, bool terse/*=true*/) {
+  // Use the terse flag to limit the level of output to one line.
+  clang::PrintingPolicy policy = decl->getASTContext().getPrintingPolicy();
+  policy.TerseOutput = terse;
+  policy.SuppressInitializers = terse;
+  policy.PolishForDeclaration = terse;
+
+  std::string buffer;
   raw_string_ostream ostream(buffer);
-  decl->print(ostream);  // Note: can also set indentation and printingpolicy
+  decl->print(ostream, policy);
   return ostream.str();
 }
 
@@ -543,7 +549,7 @@ class TypeEnumerator : public RecursiveASTVisitor<TypeEnumerator> {
 
 // A 'component' of a type is a type beneath it in the AST tree.
 // So 'Foo*' has component 'Foo', as does 'vector<Foo>', while
-// vector<pair<Foo, Bar> > has components pair<Foo,Bar>, Foo, and Bar.
+// vector<pair<Foo, Bar>> has components pair<Foo,Bar>, Foo, and Bar.
 set<const Type*> GetComponentsOfType(const Type* type) {
   TypeEnumerator type_enumerator;
   return type_enumerator.Enumerate(type);
@@ -662,7 +668,7 @@ set<FunctionDecl*> GetLateParsedFunctionDecls(TranslationUnitDecl* decl) {
 
 // Helper for the Get*ResugarMap*() functions.  Given a map from
 // desugared->resugared types, looks at each component of the
-// resugared type (eg, both hash_set<Foo>* and vector<hash_set<Foo> >
+// resugared type (eg, both hash_set<Foo>* and vector<hash_set<Foo>>
 // have two components: hash_set<Foo> and Foo), and returns a map that
 // contains the original map elements plus mapping for the components.
 // This is because when a type is 'owned' by the template
@@ -719,6 +725,23 @@ GetTplTypeResugarMapForFunctionExplicitTplArgs(
   return retval;
 }
 
+// Get the type of an expression while preserving as much type sugar as
+// possible. This was originally designed for use with function argument
+// expressions, and so might not work in a more general context.
+static const Type* GetSugaredTypeOf(const Expr* expr) {
+  // First, try to find an ImplicitCastExpr under the expr, and let that provide
+  // the type. This has a higher probability of yielding a sugared type.
+  for (const Stmt* child_expr : expr->children()) {
+    if (const auto* cast_expr = dyn_cast<ImplicitCastExpr>(child_expr)) {
+      return cast_expr->getType().getTypePtr();
+    }
+  }
+
+  // If we didn't find a type via ImplicitCastExpr, just return the type of the
+  // expr itself.
+  return GetTypeOf(expr);
+}
+
 map<const Type*, const Type*> GetTplTypeResugarMapForFunction(
     const FunctionDecl* decl, const Expr* calling_expr) {
   map<const Type*, const Type*> retval;
@@ -788,7 +811,7 @@ map<const Type*, const Type*> GetTplTypeResugarMapForFunction(
   //                 under it, take the pre-cast type instead?
   set<const Type*> fn_arg_types;
   for (unsigned i = 0; i < num_args; ++i) {
-    const Type* argtype = GetTypeOf(fn_args[i]);
+    const Type* argtype = GetSugaredTypeOf(fn_args[i]);
     // TODO(csilvers): handle RecordTypes that are a TemplateSpecializationDecl
     InsertAllInto(GetComponentsOfType(argtype), &fn_arg_types);
   }
@@ -846,9 +869,14 @@ const NamedDecl* GetDefinitionAsWritten(const NamedDecl* decl) {
     if (const ClassTemplateDecl* tpl_decl = DynCastFrom(decl))
       decl = tpl_decl->getTemplatedDecl();  // convert back to CXXRecordDecl
   } else if (const FunctionDecl* func_decl = DynCastFrom(decl)) {
-    if (const FunctionDecl* tpl_pattern =
-        func_decl->getTemplateInstantiationPattern())
-      decl = tpl_pattern;
+    // If we're instantiated from a template, use the template pattern as the
+    // decl-as-written.
+    // But avoid friend declarations in templates, something happened in Clang
+    // r283207 that caused them to form a dedicated redecl chain, separate
+    // from all other redecls.
+    const FunctionDecl* tp_decl = func_decl->getTemplateInstantiationPattern();
+    if (tp_decl && tp_decl->getFriendObjectKind() == Decl::FOK_None)
+      decl = tp_decl;
   }
   // Then, get to definition.
   if (const NamedDecl* class_dfn = GetDefinitionForClass(decl)) {
@@ -1027,6 +1055,14 @@ const Type* GetTypeOf(const Expr* expr) {
   return expr->getType().getTypePtr();
 }
 
+const Type* GetTypeOf(const CXXConstructExpr* expr) {
+  const Type* type = expr->getType().getTypePtr();
+  if (const clang::ArrayType* array_type = type->getAsArrayTypeUnsafe()) {
+    type = array_type->getElementType().getTypePtr();
+  }
+  return type;
+}
+
 const Type* GetTypeOf(const ValueDecl* decl) {
   return decl->getType().getTypePtr();
 }
@@ -1253,20 +1289,35 @@ const Type* TypeOfParentIfMethod(const CallExpr* expr) {
 }
 
 const Expr* GetFirstClassArgument(CallExpr* expr) {
-  for (CallExpr::arg_iterator it = expr->arg_begin();
-       it != expr->arg_end(); ++it) {
-    const Type* argtype = GetTypeOf(*it);
-    // Make sure we do the right thing given a function like
-    //    template <typename T> void operator>>(const T& x, ostream& os);
-    // In this case ('myclass >> os'), we want to be returning the
-    // type of os, not of myclass, and we do, because myclass will be
-    // a SubstTemplateTypeParmType, not a RecordType.
-    if (isa<SubstTemplateTypeParmType>(argtype))
-      continue;
-    argtype = argtype->getUnqualifiedDesugaredType();  // see through typedefs
-    if (isa<RecordType>(argtype) ||
-        isa<TemplateSpecializationType>(argtype)) {
-      return *it;
+  if (const FunctionDecl* callee_decl = expr->getDirectCallee()) {
+    if (isa<CXXMethodDecl>(callee_decl)) {
+      // If a method is called, return 'this'.
+      return expr->getArg(0);
+    }
+    // Handle free functions.
+    CHECK_(callee_decl->getNumParams() == expr->getNumArgs() &&
+        "Require one-to-one match between call arguments and decl parameters");
+    int params_count = callee_decl->getNumParams();
+    for (int i = 0; i < params_count; i++) {
+      // View argument types from the perspective of function declaration,
+      // not from the caller's perspective.  For example, function parameter
+      // can have template type but function argument is not necessarily
+      // a template when the function is called.
+      const Type* param_type = GetTypeOf(callee_decl->getParamDecl(i));
+      param_type = RemovePointersAndReferencesAsWritten(param_type);
+      // Make sure we do the right thing given a function like
+      //    template <typename T> void operator>>(const T& x, ostream& os);
+      // In this case ('myclass >> os'), we want to be returning the
+      // type of os, not of myclass, and we do, because myclass will be
+      // a SubstTemplateTypeParmType, not a RecordType.
+      if (isa<SubstTemplateTypeParmType>(param_type))
+        continue;
+      // See through typedefs.
+      param_type = param_type->getUnqualifiedDesugaredType();
+      if (isa<RecordType>(param_type) ||
+          isa<TemplateSpecializationType>(param_type)) {
+        return expr->getArg(i);
+      }
     }
   }
   return nullptr;
