@@ -424,7 +424,7 @@ const clang::DeclContext* GetDeclContext(const ASTNode* ast_node);
 
 string PrintableLoc(clang::SourceLocation loc);
 string PrintableSourceRange(clang::SourceRange range);
-string PrintableDecl(const clang::Decl* decl);
+string PrintableDecl(const clang::Decl* decl, bool terse=true);
 string PrintableStmt(const clang::Stmt* stmt);
 string PrintableType(const clang::Type* type);
 string PrintableTypeLoc(const clang::TypeLoc& typeloc);
@@ -521,7 +521,7 @@ set<clang::FunctionDecl*> GetLateParsedFunctionDecls(
 //    MyFunc(typedef_type)
 // clang will say this is a call to MyFunc<canonical_type>().  Also:
 //    MyFunc(my_int_vector)
-// clang will say this is MyFunc<vector<int, alloc<int> >(), with
+// clang will say this is MyFunc<vector<int, alloc<int>>(), with
 // no indication that alloc<int> is actually a default parameter.
 // Equally bad:
 //    template<class T> void OtherFunc(MyClass<T> t) { ... }
@@ -650,6 +650,8 @@ bool DeclsAreInSameClass(const clang::Decl* decl1, const clang::Decl* decl2);
 // --- Utilities for Type.
 
 const clang::Type* GetTypeOf(const clang::Expr* expr);
+// Returns the type of the constructed class.
+const clang::Type* GetTypeOf(const clang::CXXConstructExpr* expr);
 // Returns the type of the given variable, function, or enum declaration.
 const clang::Type* GetTypeOf(const clang::ValueDecl* decl);
 // ...or class, struct, union, enum, typedef, or template type.
@@ -660,7 +662,7 @@ const clang::Type* GetCanonicalType(const clang::Type* type);
 
 // A 'component' of a type is a type beneath it in the AST tree.
 // So 'Foo*' has component 'Foo', as does 'vector<Foo>', while
-// vector<pair<Foo, Bar> > has components pair<Foo,Bar>, Foo, and Bar.
+// vector<pair<Foo, Bar>> has components pair<Foo,Bar>, Foo, and Bar.
 set<const clang::Type*> GetComponentsOfType(const clang::Type* type);
 
 // The ElaborationType -- which says whether a type is preceded by
