@@ -93,16 +93,6 @@ static string GetIncludeNameAsWritten(SourceLocation include_loc) {
   return GetIncludeNameAsWritten(include_loc, DefaultDataGetter());
 }
 
-// For a particular #include line that include_loc points to,
-// returns true if the given text occurs on the line.
-// (Case sensitive.)
-static bool IncludeLineHasText(SourceLocation include_loc,
-                               const string& text) {
-  const string data = GetSourceTextUntilEndOfLine(include_loc,
-                                                  DefaultDataGetter());
-  return data.find(text) != string::npos;
-}
-
 //------------------------------------------------------------
 // Utilities on macros.
 
@@ -230,13 +220,19 @@ void IwyuPreprocessorInfo::HandlePragmaComment(SourceRange comment_range) {
 
   if (MatchTwoTokens(tokens, "private,", "include", 3, begin_loc)) {
     // 3rd token should be a quoted header.
+    const string& suggested = tokens[2];
+    if (!IsQuotedInclude(suggested)) {
+      Warn(begin_loc, "Suggested include must be a quoted header");
+      return;
+    }
+
     const string quoted_this_file
         = ConvertToQuotedInclude(GetFilePath(begin_loc));
-    MutableGlobalIncludePicker()->AddMapping(quoted_this_file, tokens[2]);
+    MutableGlobalIncludePicker()->AddMapping(quoted_this_file, suggested);
     MutableGlobalIncludePicker()->MarkIncludeAsPrivate(quoted_this_file);
     ERRSYM(this_file_entry) << "Adding private pragma-mapping: "
                             << quoted_this_file << " -> "
-                            << tokens[2] << "\n";
+                            << suggested << "\n";
     return;
   }
 
@@ -251,9 +247,15 @@ void IwyuPreprocessorInfo::HandlePragmaComment(SourceRange comment_range) {
 
   if (MatchOneToken(tokens, "no_include", 2, begin_loc)) {
     // 2nd token should be an quoted header.
-    no_include_map_[this_file_entry].insert(tokens[1]);
+    const string& inhibited = tokens[1];
+    if (!IsQuotedInclude(inhibited)) {
+      Warn(begin_loc, "Inhibited include must be a quoted header");
+      return;
+    }
+
+    no_include_map_[this_file_entry].insert(inhibited);
     ERRSYM(this_file_entry) << "Inhibiting include of "
-                            << tokens[1] << "\n";
+                            << inhibited << "\n";
     return;
   }
 
@@ -280,6 +282,13 @@ void IwyuPreprocessorInfo::HandlePragmaComment(SourceRange comment_range) {
     return;
   }
 
+  if (MatchOneToken(tokens, "associated", 1, begin_loc)) {
+    if (associated_pragma_location_.isInvalid()) {
+      associated_pragma_location_ = begin_loc;
+    }
+    return;
+  }
+
   // "keep" and "export" are handled in MaybeProtectInclude.
   if (!MatchOneToken(tokens, "keep", 1, begin_loc)
       && !MatchOneToken(tokens, "export", 1, begin_loc)) {
@@ -386,13 +395,13 @@ void IwyuPreprocessorInfo::MaybeProtectInclude(
   // TODO(dsturtevant): As written "// // IWYU pragma: keep" is incorrectly
   // interpreted as a pragma. Maybe do "keep" and "export" pragma handling
   // in HandleComment?
-  if (IncludeLineHasText(includer_loc, "// IWYU pragma: keep") ||
-      IncludeLineHasText(includer_loc, "/* IWYU pragma: keep")) {
+  if (LineHasText(includer_loc, "// IWYU pragma: keep") ||
+      LineHasText(includer_loc, "/* IWYU pragma: keep")) {
     protect_reason = "pragma_keep";
     FileInfoFor(includer)->ReportKnownDesiredFile(includee);
 
-  } else if (IncludeLineHasText(includer_loc, "// IWYU pragma: export") ||
-             IncludeLineHasText(includer_loc, "/* IWYU pragma: export") ||
+  } else if (LineHasText(includer_loc, "// IWYU pragma: export") ||
+             LineHasText(includer_loc, "/* IWYU pragma: export") ||
              HasOpenBeginExports(includer)) {
     protect_reason = "pragma_export";
     const string quoted_includer =
@@ -509,6 +518,22 @@ void IwyuPreprocessorInfo::AddDirectInclude(
              << " as associated header of " << GetFilePath(includer) << ".\n";
   }
 
+  // Besides marking headers as "associated header" with heuristics, the user
+  // can directly mark headers with the associated pragma.
+  const FileEntry* associated_includer =
+      GetFileEntry(associated_pragma_location_);
+  if (associated_pragma_location_.isValid() &&
+      associated_includer == includer) {
+    GetFromFileInfoMap(includer)->AddAssociatedHeader(
+        GetFromFileInfoMap(includee));
+    VERRS(4) << "Marked " << GetFilePath(includee)
+             << " as associated header of " << GetFilePath(includer)
+             << " due to associated pragma.\n";
+
+    AddGlobToReportIWYUViolationsFor(GetFilePath(includee));
+    associated_pragma_location_ = SourceLocation();
+  }
+
   // Also keep track of what FileEntry we ended up using for this name.
   // Because we use #include-next, the same include-name can map to
   // several files; we use the first such mapping we see, which is the
@@ -673,6 +698,9 @@ void IwyuPreprocessorInfo::FileSkipped(const FileEntry& file,
       << " (" << GetFilePath(&file) << ")\n";
 
   AddDirectInclude(include_loc, &file, include_name_as_written);
+  if (ShouldReportIWYUViolationsFor(&file)) {
+    files_to_report_iwyu_violations_for_.insert(&file);
+  }
 }
 
 // Called when a file is #included.
@@ -830,7 +858,7 @@ void IwyuPreprocessorInfo::PopulateIntendsToProvideMap() {
   CHECK_(intends_to_provide_map_.empty() && "Should only call this fn once");
   // Figure out which of the header files we have are public.  We'll
   // map each one to a set of all private header files that map to it.
-  map<const FileEntry*, set<const FileEntry*> > private_headers_behind;
+  map<const FileEntry*, set<const FileEntry*>> private_headers_behind;
   for (const auto& fileinfo : iwyu_file_info_map_) {
     const FileEntry* header = fileinfo.first;
     const vector<string> public_headers_for_header =
