@@ -26,6 +26,7 @@ import json
 import argparse
 import subprocess
 import re
+import multiprocessing
 
 
 def iwyu_formatter(output):
@@ -95,10 +96,22 @@ def get_output(cwd, command):
     return process.communicate()[0].decode("utf-8").splitlines()
 
 
-def run_iwyu(cwd, compile_command, iwyu_args, verbose, formatter):
+def run_iwyu(dbentry, iwyu_args, verbose):
     """ Rewrite compile_command to an IWYU command, and run it. """
-    compiler, _, args = compile_command.partition(' ')
-    if compiler.endswith('cl.exe'):
+    cwd = dbentry['directory']
+
+    if 'arguments' in dbentry:
+        # arguments is a command-line in list form
+        arguments = dbentry['arguments']
+        compile_command, compile_args = arguments[0], arguments[1:]
+        compile_args = ' '.join(compile_args)
+    elif 'command' in dbentry:
+        # command is a command-line in string form
+        compile_command, _, compile_args = dbentry['command'].partition(' ')
+    else:
+        raise ValueError('Invalid compilation database entry: %s' % dbentry)
+
+    if compile_command.endswith('cl.exe'):
         # If the compiler name is cl.exe, let IWYU be cl-compatible
         clang_args = ['--driver-mode=cl']
     else:
@@ -106,15 +119,15 @@ def run_iwyu(cwd, compile_command, iwyu_args, verbose, formatter):
 
     iwyu_args = ['-Xiwyu ' + a for a in iwyu_args]
     command = ['include-what-you-use'] + clang_args + iwyu_args
-    command = '%s %s' % (' '.join(command), args.strip())
+    command = '%s %s' % (' '.join(command), compile_args.strip())
 
     if verbose:
         print('%s:' % command)
 
-    formatter(get_output(cwd, command))
+    return get_output(cwd, command)
 
 
-def main(compilation_db_path, source_files, verbose, formatter, iwyu_args):
+def main(compilation_db_path, source_files, verbose, formatter, jobs, iwyu_args):
     """ Entry point. """
     # Canonicalize compilation database path
     if os.path.isdir(compilation_db_path):
@@ -153,9 +166,19 @@ def main(compilation_db_path, source_files, verbose, formatter, iwyu_args):
 
     # Run analysis
     try:
+
+        pool = multiprocessing.Pool(jobs)
+        # No actual results in `results`, it's only used for exception handling.
+        # Details here: https://stackoverflow.com/a/28660669.
+        results = []
         for entry in entries:
-            cwd, compile_command = entry['directory'], entry['command']
-            run_iwyu(cwd, compile_command, iwyu_args, verbose, formatter)
+            results.append(pool.apply_async(run_iwyu,
+                                            (entry, iwyu_args, verbose),
+                                            callback=formatter))
+        pool.close()
+        pool.join()
+        for r in results:
+            r.get()
     except OSError as why:
         print('ERROR: Failed to launch include-what-you-use: %s' % why)
         return 1
@@ -198,6 +221,8 @@ def _bootstrap():
     parser.add_argument('-o', '--output-format', type=str,
                         choices=FORMATTERS.keys(), default=DEFAULT_FORMAT,
                         help='Output format (default: %s)' % DEFAULT_FORMAT)
+    parser.add_argument('-j', '--jobs', type=int, default=1,
+                        help='Number of concurrent subprocesses')
     parser.add_argument('-p', metavar='<build-path>', required=True,
                         help='Compilation database path', dest='dbpath')
     parser.add_argument('source', nargs='*',
@@ -215,7 +240,7 @@ def _bootstrap():
     args = parser.parse_args(argv)
 
     sys.exit(main(args.dbpath, args.source, args.verbose,
-                  FORMATTERS[args.output_format], iwyu_args))
+                  FORMATTERS[args.output_format], args.jobs, iwyu_args))
 
 
 if __name__ == '__main__':
