@@ -9,8 +9,8 @@
 
 // This module controls logging and verbosity levels for include-what-you-use.
 
-#ifndef DEVTOOLS_MAINTENANCE_INCLUDE_WHAT_YOU_USE_IWYU_VERRS_H_
-#define DEVTOOLS_MAINTENANCE_INCLUDE_WHAT_YOU_USE_IWYU_VERRS_H_
+#ifndef INCLUDE_WHAT_YOU_USE_IWYU_VERRS_H_
+#define INCLUDE_WHAT_YOU_USE_IWYU_VERRS_H_
 
 #include "llvm/Support/raw_ostream.h"
 
@@ -40,6 +40,13 @@ bool ShouldPrintSymbolFromFile(const clang::FileEntry* file);
   if (!::include_what_you_use::ShouldPrint( \
           verbose_level)) ; else ::llvm::errs()
 
+// Prints to errs() if the verbose level is at a high enough level to
+// print symbols that occur in the given file.  This is only valid
+// when used inside a class, such as IwyuAstConsumer, that defines a
+// method named ShouldPrintSymbolFromFile().
+#define ERRSYM(file_entry) \
+  if (!ShouldPrintSymbolFromFile(file_entry)) ; else ::llvm::errs()
+
 }  // namespace include_what_you_use
 
-#endif  // DEVTOOLS_MAINTENANCE_INCLUDE_WHAT_YOU_USE_IWYU_VERRS_H_
+#endif  // INCLUDE_WHAT_YOU_USE_IWYU_VERRS_H_
