@@ -7,9 +7,9 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef DEVTOOLS_MAINTENANCE_INCLUDE_WHAT_YOU_USE_CATCH_BYVALUE_H_
-#define DEVTOOLS_MAINTENANCE_INCLUDE_WHAT_YOU_USE_CATCH_BYVALUE_H_
+#ifndef INCLUDE_WHAT_YOU_USE_TESTS_CXX_CATCH_BYVALUE_H_
+#define INCLUDE_WHAT_YOU_USE_TESTS_CXX_CATCH_BYVALUE_H_
 
 class CatchByValue {};
 
-#endif // DEVTOOLS_MAINTENANCE_INCLUDE_WHAT_YOU_USE_CATCH_BYVALUE_H_
+#endif // INCLUDE_WHAT_YOU_USE_TESTS_CXX_CATCH_BYVALUE_H_
